==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/CookieExpirationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.CookieExpirationArgs.builder
import com.pulumi.azurenative.web.kotlin.enums.CookieExpirationConvention
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The configuration settings of the session cookie's expiration.
 * @property convention The convention used when determining the session cookie's expiration.
 * @property timeToExpiration The time after the request is made when the session cookie should expire.
 */
public data class CookieExpirationArgs(
    public val convention: Output<CookieExpirationConvention>? = null,
    public val timeToExpiration: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.CookieExpirationArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.CookieExpirationArgs =
        com.pulumi.azurenative.web.inputs.CookieExpirationArgs.builder()
            .convention(convention?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .timeToExpiration(timeToExpiration?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CookieExpirationArgs].
 */
@PulumiTagMarker
public class CookieExpirationArgsBuilder internal constructor() {
    private var convention: Output<CookieExpirationConvention>? = null

    private var timeToExpiration: Output<String>? = null

    /**
     * @param value The convention used when determining the session cookie's expiration.
     */
    @JvmName("hqvjlviixndeeqdv")
    public suspend fun convention(`value`: Output<CookieExpirationConvention>) {
        this.convention = value
    }

    /**
     * @param value The time after the request is made when the session cookie should expire.
     */
    @JvmName("exqsiddjtxoexpso")
    public suspend fun timeToExpiration(`value`: Output<String>) {
        this.timeToExpiration = value
    }

    /**
     * @param value The convention used when determining the session cookie's expiration.
     */
    @JvmName("bnjssxxbjtscnesx")
    public suspend fun convention(`value`: CookieExpirationConvention?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.convention = mapped
    }

    /**
     * @param value The time after the request is made when the session cookie should expire.
     */
    @JvmName("ywffkrfvckdkkbfw")
    public suspend fun timeToExpiration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeToExpiration = mapped
    }

    internal fun build(): CookieExpirationArgs = CookieExpirationArgs(
        convention = convention,
        timeToExpiration = timeToExpiration,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/CookieExpirationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.CookieExpirationArgs.builder
import com.pulumi.azurenative.web.kotlin.enums.CookieExpirationConvention
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The configuration settings of the session cookie's expiration.
 * @property convention The convention used when determining the session cookie's expiration.
 * @property timeToExpiration The time after the request is made when the session cookie should expire.
 */
public data class CookieExpirationArgs(
    public val convention: Output<CookieExpirationConvention>? = null,
    public val timeToExpiration: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.CookieExpirationArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.CookieExpirationArgs =
        com.pulumi.azurenative.web.inputs.CookieExpirationArgs.builder()
            .convention(convention?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .timeToExpiration(timeToExpiration?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CookieExpirationArgs].
 */
@PulumiTagMarker
public class CookieExpirationArgsBuilder internal constructor() {
    private var convention: Output<CookieExpirationConvention>? = null

    private var timeToExpiration: Output<String>? = null

    /**
     * @param value The convention used when determining the session cookie's expiration.
     */
    @JvmName("nhtjhaxkxjaqykxs")
    public suspend fun convention(`value`: Output<CookieExpirationConvention>) {
        this.convention = value
    }

    /**
     * @param value The time after the request is made when the session cookie should expire.
     */
    @JvmName("lfffrgfyyuxaetrn")
    public suspend fun timeToExpiration(`value`: Output<String>) {
        this.timeToExpiration = value
    }

    /**
     * @param value The convention used when determining the session cookie's expiration.
     */
    @JvmName("lwyinibufixolqek")
    public suspend fun convention(`value`: CookieExpirationConvention?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.convention = mapped
    }

    /**
     * @param value The time after the request is made when the session cookie should expire.
     */
    @JvmName("nqnmtspyxruysnhx")
    public suspend fun timeToExpiration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeToExpiration = mapped
    }

    internal fun build(): CookieExpirationArgs = CookieExpirationArgs(
        convention = convention,
        timeToExpiration = timeToExpiration,
    )
}
